import React, { useState, useCallback, useEffect } from 'react';
import ReactDOM from 'react-dom';
import { select, axisLeft, axisBottom, csv, arc, pie, scaleBand, scaleLinear, max, format} from 'd3';

const myData = 'https://gist.githubusercontent.com/Platoch/849bf61f1aa332b8493d96d8a841974a/raw/1c67a40b7b803af4c4d568eb29ac12b1d7fd2397/ICE6_data.csv'
const width = 960;
const height = 500;
const margin = { top: 20, right: 50, bottom: 50, left: 80 };

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    const row = d => {
      return d;
    };
    csv(myData, row).then(data => {
      setData(data.slice(0, 5));
    });
  }, []);

  if (!data) {
    return <pre>Loading...</pre>;
  }

  const innerHeight = height - margin.top - margin.bottom - 100;
  const innerWidth = width - margin.left - margin.right;

  const yScale = scaleBand()
    .domain(data.map(d => d.Item))
    .range([0, innerHeight]);

  const xScale = scaleLinear()
    .domain([0, max(data, d => d.Total)])
    .range([0, innerWidth]);

  
  return (
    <svg width={width} height={height}>
      <g transform={`translate(${margin.left},${margin.top})`}>
        {xScale.ticks().map(tickValue => (
          <g key={tickValue} transform={`translate(${xScale(tickValue)},0)`}>
            <line y2={innerHeight} stroke="blue" />
            <text
              style={{ textAnchor: 'middle' }}
              dy=".70em"
              y={innerHeight + 3}
            >
              {tickValue}
            </text>
          </g>
        ))}
        {yScale.domain().map(tickValue => (
          <text
            key={tickValue}
            style={{ textAnchor: 'end' }}
            x={-3}
            dy=".32em"
            y={yScale(tickValue) + yScale.bandwidth() / 2}
          >
            {tickValue}
          </text>
        ))}
        {data.map(d => (
          <rect
            key={d.Item}
            x={0}
            y={yScale(d.Item)}
            width={xScale(d.Total)}
            height={yScale.bandwidth()}
          />
        ))}
      </g>
    </svg>
  );
  
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);